==> sagua_0.1.2-1.tar.gz: sagua-0.1.2/include/mainwin.h <==
#ifndef GUARD_mainwin_h
#define GUARD_mainwin_h
// Sagua is music player.
// Copyright (C) 2004 HG, Rhee <ez8tank@krpost.net>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

/// @file mainwin.h
/// @brief Class for main window header file.

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <vector>
#include <string>

#include <glibmm.h>
#include <gtkmm/window.h>
#include <gtkmm/box.h>
#include <gtkmm/label.h>
#include <gtkmm/menu.h>
#include <gtkmm/menubar.h>
#include <gtkmm/checkmenuitem.h>
#include <gtkmm/radiobuttongroup.h>
#include <gtkmm/radiomenuitem.h>
#include <gtkmm/alignment.h>
#include <gtkmm/scale.h>
#include <gtkmm/button.h>
#include <gtkmm/toolbar.h>
#include <gtkmm/toolbutton.h>
#include <gtkmm/scrolledwindow.h>

#include "imagebutton.h"

class MainManager;
class Player;
class PlayerFactory;
class Playlist;

/// @brief Class for main window.
class MainWnd : public Gtk::Window
{
    friend class Playlist;
    
    public:
	MainWnd(MainManager& mainManager, const std::vector<std::string>& arguments);
	~MainWnd();

	void FinishPlay();
	void TimeUpdate();

	bool IsPlayable(const std::string& filename); 

	/// @brief Store last browsed directory in DirPlayWnd.
	void LogBrowsedDirectory(const std::string& dir) { lastBrowsedDirectory_ = dir; }
	/// @brief Get last browsed directory.
	const std::string& GetLastBrowsedDirectory() const { return lastBrowsedDirectory_; }

	void OnBtnPlay();
	void OnBtnNext();
	void OnBtnPrev();
	void OnBtnStop();

	void OnMenuPreference();

	void OnMenuQuit();

	/// @brief Thread is running or not.
	bool InPlay()
	{
	    return inThread_;
	}
	
	/// @brief Stop play for set changed driver.
	///
	/// Stop play and call MainManager::AudioSetDriverFromPreference to 
	/// set changed driver in MainWnd::FinishPlay. 
	void StopPlayForSetDriver()
	{
	    if(!breakPlayForSetDriver_) {
		breakPlayForSetDriver_ = true;

		OnBtnStop();
	    }
	}

	void CurrentFileInfo();

	void SaveState();

	/// @brief Set to skip time display update.
	void SetSkipTimeUpdate(const bool& active) { skipTimeUpdate_ = active; }

	void RefreshMixer();
	void VolumnIncrease();
	void VolumnDecrease();

	void PushNewListFromSocket(const std::vector<std::string>& list);

    private:
	MainManager& mainManager_;

	std::auto_ptr<Player> player_;
	std::auto_ptr<PlayerFactory> playerFactory_;
	Playlist* playlist_;

	Gtk::VBox mainBox_, playerBox_;
	Gtk::HBox playCtlBox_, timeDisplayBox_, playerBoxWithVolumn_;
	std::auto_ptr<Gtk::HBox> viewBox_;
	Gtk::MenuBar menuBar_;
	Gtk::Menu fileMenu_, editMenu_, viewMenu_, helpMenu_;
	Gtk::CheckMenuItem randomPlayMenu_, repeatPlayMenu_, compactPlayMenu_;
	Gtk::RadioButtonGroup viewMenuGroup_;
	Gtk::RadioMenuItem mainlistPlayMenu_, dirPlayMenu_;
	Gtk::Label displayLabel_, timeLabel_, totalTimeLabel_;
	Gtk::Alignment titleDisplayAlignment_, seekScaleAlignment_, volumnAlignment_;
	Gtk::HScale seekScale_;
	Gtk::VScale volumnScale_;
	ImageButton playImgBtn_, pauseImgBtn_, stopImgBtn_, prevImgBtn_, nextImgBtn_;
	Gtk::ScrolledWindow* scrolledWindow_;

	int prevWidth_, prevHeight_;
	const int defaultWidth_, defaultHeight_;
	const int defaultCompactWidth_, defaultCompactHeight_;

	Glib::Thread* execThread_;
	bool inThread_;
	bool inPlay_;
	bool breakPlay_;
	bool breakPlayForSetDriver_;
	bool randomPlay_;
	bool repeatPlay_;

	bool skipTimeUpdate_;

	enum ListState {
	    LISTSTATE_EMPTY = 3,
	    LISTSTATE_LAST = 2,
	    LISTSTATE_FIRST = 1,
	    LISTSTATE_NORMAL = 0
	};

	ListState listState_;

	std::string selectedFile_;
	std::string lastBrowsedDirectory_;
	std::vector<std::string> selectedFilesVector_;

	virtual bool on_delete_event(GdkEventAny*);
	virtual bool on_window_state_event(GdkEventWindowState*);

	void OnMenuFileAdd();
	void OnMenuFileDirAdd();
	void OnMenuRepeat();
	void OnMenuRandom();
	void OnMenuViewMainList();
	void OnMenuViewDir();
	void OnMenuCompactView();

	void OnScaleSeek(const double&);

	void LoadEmptyMainList();

	void DisplayTitle(const Glib::ustring& title, const bool& clear = false);
	void DisplayTotalTime(const Glib::ustring& time);
	/// @brief Display time and set sensitive to seek bar or not.
	void DisplayVisualPanel(const bool& flag)
	{
	    if(flag) {
		timeLabel_.show();
		totalTimeLabel_.show();
		seekScale_.set_sensitive(true);	
	    } else {
		timeLabel_.hide();
		totalTimeLabel_.hide();
		seekScale_.set_sensitive(false);
	    }	
	}
	void SetSeekScaleRange(const unsigned int& max);

	void LoadLastState(const bool& hasArguments);

	struct AddToPlaylist;
	struct AddToPlaylistExceptListfile;
	
};

#endif

==> sagua_0.2.0-1.tar.gz: sagua-0.2.0/include/mainwin.h <==
#ifndef GUARD_mainwin_h
#define GUARD_mainwin_h
// Sagua is music player.
// Copyright (C) 2004 HG, Rhee <ez8tank@krpost.net>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

/// @file mainwin.h
/// @brief Class for main window header file.

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <vector>
#include <string>

#include <glibmm.h>
#include <gtkmm/window.h>
#include <gtkmm/box.h>
#include <gtkmm/label.h>
#include <gtkmm/menu.h>
#include <gtkmm/menubar.h>
#include <gtkmm/checkmenuitem.h>
#include <gtkmm/radiobuttongroup.h>
#include <gtkmm/radiomenuitem.h>
#include <gtkmm/alignment.h>
#include <gtkmm/scale.h>
#include <gtkmm/button.h>
#include <gtkmm/toolbar.h>
#include <gtkmm/toolbutton.h>
#include <gtkmm/scrolledwindow.h>
#include <gtkmm/eventbox.h>

#include "imagebutton.h"

class MainManager;
class Player;
class PlayerFactory;
class Playlist;

/// @brief Class for main window.
class MainWnd : public Gtk::Window
{
    friend class Playlist;
    
    public:
	MainWnd(MainManager& mainManager, const std::vector<std::string>& arguments);
	~MainWnd();

	void FinishPlay();
	void TimeUpdate();

	bool IsPlayable(const std::string& filename); 

	/// @brief Store last browsed directory in DirPlayWnd.
	void LogBrowsedDirectory(const std::string& dir) { lastBrowsedDirectory_ = dir; }
	/// @brief Get last browsed directory.
	const std::string& GetLastBrowsedDirectory() const { return lastBrowsedDirectory_; }

	void OnBtnPlay();
	void OnBtnNext();
	void OnBtnPrev();
	void OnBtnStop();

	void OnMenuPreference();

	void OnMenuQuit();

	/// @brief Thread is running or not.
	bool InPlay()
	{
	    return inThread_;
	}
	
	/// @brief Stop play for set changed driver.
	///
	/// Stop play and call MainManager::AudioSetDriverFromPreference to 
	/// set changed driver in MainWnd::FinishPlay. 
	void StopPlayForSetDriver()
	{
	    if(!breakPlayForSetDriver_) {
		breakPlayForSetDriver_ = true;

		OnBtnStop();
	    }
	}

	void CurrentFileInfo();

	void SaveState();

	/// @brief Set to skip time display update.
	void SetSkipTimeUpdate(const bool& active) { skipTimeUpdate_ = active; }

	void RefreshMixer();
	void VolumnIncrease();
	void VolumnDecrease();

	void PushNewListFromSocket(const std::vector<std::string>& list);
	void ChangeCompactBgPixmap();

	void PlayQueue()
	{
	    if(playQueue_) {
		playQueue_ = false;
		OnBtnPlay();
	    }
	}

    private:
	MainManager& mainManager_;

	std::auto_ptr<Player> player_;
	std::auto_ptr<PlayerFactory> playerFactory_;
	Playlist* playlist_;

	Gtk::VBox mainBox_, playerBox_, compactPlayCtlBox_;
	Gtk::HBox playCtlBox_, compactPlayCtlHBox_, timeDisplayBox_, playerBoxWithVolumn_;
	std::auto_ptr<Gtk::HBox> viewBox_;
	Gtk::MenuBar menuBar_;
	Gtk::Menu fileMenu_, editMenu_, viewMenu_, helpMenu_;
	Gtk::CheckMenuItem randomPlayMenu_, repeatPlayMenu_, compactPlayMenu_;
	Gtk::RadioButtonGroup viewMenuGroup_;
	Gtk::RadioMenuItem mainlistPlayMenu_, dirPlayMenu_;
	Gtk::Label displayLabel_, timeLabel_, totalTimeLabel_;
	Gtk::Alignment titleDisplayAlignment_, seekScaleAlignment_, volumnAlignment_;
	Gtk::EventBox titleDisplayEventBox_;
	Gtk::HScale seekScale_;
	Gtk::VScale volumnScale_;
	ImageButton playImgBtn_, pauseImgBtn_, stopImgBtn_, prevImgBtn_, nextImgBtn_;
	ImageButton compactPlayImgBtn_, compactPauseImgBtn_, compactStopImgBtn_, compactPrevImgBtn_, compactNextImgBtn_;
	Gtk::ScrolledWindow* scrolledWindow_;
	Glib::RefPtr<Gtk::RcStyle> titleDisplayEventBoxDefaultStyle_;
	Glib::RefPtr<Gtk::RcStyle> mainWndDefaultStyle_;

	int prevWidth_, prevHeight_;
	const int defaultWidth_, defaultHeight_;
	const int defaultCompactWidth_, defaultCompactHeight_;

	Glib::Thread* execThread_;
	bool inThread_;
	bool inPlay_;
	bool breakPlay_;
	bool breakPlayForSetDriver_;
	bool randomPlay_;
	bool repeatPlay_;

	bool skipTimeUpdate_;

	bool playQueue_;

	enum ListState {
	    LISTSTATE_EMPTY = 3,
	    LISTSTATE_LAST = 2,
	    LISTSTATE_FIRST = 1,
	    LISTSTATE_NORMAL = 0
	};

	ListState listState_;

	std::string selectedFile_;
	std::string lastBrowsedDirectory_;
	Glib::ustring lastTitle_;
	std::vector<std::string> selectedFilesVector_;

	virtual bool on_delete_event(GdkEventAny*);
	virtual bool on_window_state_event(GdkEventWindowState*);

	void OnMenuFileAdd();
	void OnMenuFileDirAdd();
	void OnMenuRepeat();
	void OnMenuRandom();
	void OnMenuViewMainList();
	void OnMenuViewDir();
	void OnMenuCompactView();

	void OnScaleSeek(const double&);

	bool OnButtonPressInDisplayLabel(GdkEventButton* ev);

	void SetBackgroundPixmapInCompactMode();
	void UnsetBackgroundPixmapInCompactMode();

	void LoadEmptyMainList();

	void DisplayTitle(const Glib::ustring& title, const bool& clear = false);
	void DisplayTotalTime(const Glib::ustring& time);
	/// @brief Display time and set sensitive to seek bar or not.
	void DisplayVisualPanel(const bool& flag)
	{
	    if(flag) {
		timeLabel_.show();
		totalTimeLabel_.show();
		seekScale_.set_sensitive(true);	
	    } else {
		timeLabel_.hide();
		totalTimeLabel_.hide();
		seekScale_.set_sensitive(false);
	    }	
	}
	void SetSeekScaleRange(const unsigned int& max);

	void LoadLastState(const bool& hasArguments);

};

#endif
